==> rust-wasmtime_16.0.0+dfsg.orig.tar.xz: wasmtime-16.0.0/ADOPTERS.md <==
# Wasmtime adopters

_If you are using wasmtime in production at your organization, please add your company name to this list.
The list is in alphabetical order._

Wasmtime is used in many different production use-cases. This list has grown significantly since the [first major version release in 2022](https://bytecodealliance.org/articles/wasmtime-1-0-fast-safe-and-production-ready).

| Organization | Contact | Status | Description of Use |
| - | - | - | - |
| [Cosmonic](https://www.cosmonic.com) | [@ricochet](https://github.com/ricochet) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | Cosmonic is a distributed app platform built on CNCF wasmCloud for wasmCloud apps. |
| [DFINITY](https://dfinity.org/) | [@ulan](https://github.com/ulan) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | Internet Computer blockchain uses Wasmtime to run canister smart contracts. |
| [Embark Studios](https://www.embark-studios.com/) | [@repi](https://github.com/repi) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | Rust game engine |
| [Fastly](https://fastly.com/) | [@fitzgen](https://github.com/fitzgen) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | The Compute@Edge platform helps you compile your custom code to WebAssembly and runs it at the Fastly edge using the WebAssembly System Interface for each compute request. |
| [Fermyon](https://fermyon.com) | [@tschneidereit](https://github.com/tschneidereit) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | Fermyon Cloud is a cloud application platform for WebAssembly-based serverless functions and microservices. |
| [InfinyOn](https://infinyon.com/) | [@sehz](https://github.com/sehz) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | InfinyOn leverages the power of WebAssembly SmartModules to execute real-time data transformations. |
| [Microsoft](https://microsoft.com/) | [@devigned](https://gist.github.com/devigned) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | Microsoft has had Wasmtime in preview for its WebAssembly System Interface (WASI) node pools in Azure Kubernetes Service since October 2021. |
| [Shopify](https://www.shopify.com/) | [@saulecabrera](https://github.com/saulecabrera) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | Shopify Functions allow developers to customize the backend logic of Shopify. |
| [SingleStore](https://www.singlestore.com/) | [@Kylebrown9](https://github.com/Kylebrown9) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | SingleStoreDB Cloud embeds Wasmtime to bring developers' code to the data, safely and with speed and scale. |

==> rust-wasmtime_19.0.0+dfsg.orig.tar.xz: wasmtime-19.0.0/ADOPTERS.md <==
# Wasmtime adopters

_If you are using wasmtime in production at your organization, please add your company name to this list.
The list is in alphabetical order._

Wasmtime is used in many different production use-cases. This list has grown significantly since the [first major version release in 2022](https://bytecodealliance.org/articles/wasmtime-1-0-fast-safe-and-production-ready).

| Organization | Contact | Status | Description of Use |
| - | - | - | - |
| [Cosmonic](https://www.cosmonic.com) | [@ricochet](https://github.com/ricochet) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | Cosmonic is a distributed app platform built on CNCF wasmCloud for wasmCloud apps. |
| [DFINITY](https://dfinity.org/) | [@ulan](https://github.com/ulan) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | Internet Computer blockchain uses Wasmtime to run canister smart contracts. |
| [Embark Studios](https://www.embark-studios.com/) | [@repi](https://github.com/repi) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | Rust game engine |
| [Fastly](https://fastly.com/) | [@fitzgen](https://github.com/fitzgen) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | The Compute@Edge platform helps you compile your custom code to WebAssembly and runs it at the Fastly edge using the WebAssembly System Interface for each compute request. |
| [Fermyon](https://fermyon.com) | [@tschneidereit](https://github.com/tschneidereit) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | Fermyon Cloud is a cloud application platform for WebAssembly-based serverless functions and microservices. |
| [InfinyOn](https://infinyon.com/) | [@sehz](https://github.com/sehz) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | InfinyOn leverages the power of WebAssembly SmartModules to execute real-time data transformations. |
| [Microsoft](https://microsoft.com/) | [@devigned](https://gist.github.com/devigned) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | Microsoft has had Wasmtime in preview for its WebAssembly System Interface (WASI) node pools in Azure Kubernetes Service since October 2021. |
| [Redpanda](https://redpanda.com/) | [@rockwotj](https://github.com/rockwotj) | ![beta](https://img.shields.io/badge/-beta-orange?style=flat) | Redpanda Data Transforms allow developers to transform data directly in the message broker. |
| [Shopify](https://www.shopify.com/) | [@saulecabrera](https://github.com/saulecabrera) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | Shopify Functions allow developers to customize the backend logic of Shopify. |
| [SingleStore](https://www.singlestore.com/) | [@pvetere](https://github.com/pvetere) | ![production](https://img.shields.io/badge/-production-blue?style=flat) | SingleStoreDB Cloud embeds Wasmtime to bring developers' code to the data, safely and with speed and scale. |
